"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getInstallationScript = getInstallationScript;
exports.getStopScript = getStopScript;
exports.start = start;
exports.stop = stop;
var _debug = _interopRequireDefault(require("debug"));
var _child_process = require("child_process");
var _postgres = _interopRequireDefault(require("postgres"));
var _util = require("util");
var _cwd = _interopRequireDefault(require("cwd"));
var _os = require("os");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const asyncExec = (0, _util.promisify)(_child_process.exec);
const debug = (0, _debug.default)('postgres-local');
const FILEPATH_PREFIX = `${(0, _cwd.default)()}/node_modules/.cache/@shelf/postgres-local`;
async function start(options) {
  const {
    seedPath,
    version = 14,
    useSudo = false
  } = options;
  const url = 'postgres://localhost:5432/postgres';
  try {
    await asyncExec(getInstallationScript({
      version,
      useSudo
    }));
    debug('Connecting to postgres...');
    const sql = (0, _postgres.default)(url);
    debug('Postgres available!');
    process.env.PSQL = url;
    if (seedPath !== null && seedPath !== void 0 && seedPath.length) {
      debug('Found seed file, seeding...');
      await sql.file(seedPath);
      debug('Seed done available!');
    }
    return url;
  } catch (e) {
    console.error(e);
    throw e;
  }
}
async function stop({
  version = 14,
  useSudo = false
}) {
  return asyncExec(getStopScript({
    version,
    useSudo
  }));
}
function getInstallationScript({
  version = 14,
  useSudo = false
}) {
  const prefix = useSudo ? 'sudo' : '';
  switch ((0, _os.platform)()) {
    case 'darwin':
      {
        return `
        ${prefix} brew install postgresql@${version};
        ${prefix} mkdir -p ${FILEPATH_PREFIX}/data;
        ${prefix} initdb -D ${FILEPATH_PREFIX}/data;
        ${prefix} pg_ctl -D ${FILEPATH_PREFIX}/data -l ${FILEPATH_PREFIX}/logfile start;
      `;
      }
    case 'win32':
      {
        throw new Error('Unsupported OS, try run on OS X or Linux');
      }
    default:
      {
        return `
        ${prefix} apt update;
        ${prefix} apt install postgresql-${version};
        ${prefix} mkdir -p ${FILEPATH_PREFIX}/data;
        ${prefix} /usr/lib/postgresql/${version}/bin/initdb -D ${FILEPATH_PREFIX}/data;
        ${prefix} /usr/lib/postgresql/${version}/bin/pg_ctl -D ${FILEPATH_PREFIX}/data -l ${FILEPATH_PREFIX}logfile start;
      `;
      }
  }
}
function getStopScript({
  version = 14,
  useSudo = false
}) {
  const prefix = useSudo ? 'sudo' : '';
  switch ((0, _os.platform)()) {
    case 'darwin':
      {
        return `
         ${prefix} pg_ctl stop -D ${FILEPATH_PREFIX}/data
         ${prefix} rm -rf ${FILEPATH_PREFIX}
      `;
      }
    default:
      {
        return `
        ${prefix} /usr/lib/postgresql/${version}/bin/pg_ctl -D ${FILEPATH_PREFIX}/data
        ${prefix} rm -rf ${FILEPATH_PREFIX}
      `;
      }
  }
}